declare enum PlaybackType {
    html5 = 0,
    webaudio = 1
}
declare enum PlaybackLoadingState {
    none = 0,
    loading = 1,
    loaded = 2
}
export interface QueueOptions {
    onProgress?: () => void;
    onEnded?: () => void;
    onPlayNextTrack?: () => void;
    onPlayPreviousTrack?: () => void;
    onStartNewTrack?: () => void;
    webAudioIsDisabled?: boolean;
    debug?: ((message: string, ...optionalParams: any[]) => void) | null;
    numberOfTracksToPreload?: number;
}
interface QueueState {
    volume: number;
    currentTrackIndex: number;
    webAudioIsDisabled: boolean;
}
declare global {
    interface Window {
        webkitAudioContext: AudioContext;
    }
}
export declare class Queue<TTrackMetadata> {
    private props;
    private numberOfTracksToPreload;
    readonly tracks: Track<TTrackMetadata>[];
    state: QueueState;
    constructor({ onProgress, onEnded, onPlayNextTrack, onPlayPreviousTrack, onStartNewTrack, webAudioIsDisabled, numberOfTracksToPreload }?: QueueOptions);
    addTrack({ trackUrl, metadata }: {
        trackUrl: string;
        metadata: TTrackMetadata;
    }): void;
    removeTrack(track: Track<TTrackMetadata>): void;
    togglePlayPause(): Promise<void>;
    play(): Promise<void>;
    pause(): void;
    playPrevious(): Promise<void>;
    playNext(): Promise<void>;
    resetCurrentTrack(): void;
    pauseAll(): void;
    gotoTrack(trackIndex: number, playImmediately?: boolean): Promise<void>;
    loadTrack(trackIndex: number, useHtmlAudioPreloading?: boolean): void;
    notifyTrackEnded(): void;
    notifyTrackProgressUpdated(): void;
    get currentTrack(): Track<TTrackMetadata>;
    get nextTrack(): Track<TTrackMetadata>;
    disableWebAudio(): void;
    setVolume(volume: number): void;
}
interface TrackOptions<TTrackMetadata> {
    trackUrl: string;
    queue: Queue<TTrackMetadata>;
    index: number;
    metadata: TTrackMetadata;
}
interface LimitedTrackState {
    playbackType: PlaybackType;
    webAudioLoadingState: PlaybackLoadingState;
}
interface TrackState extends LimitedTrackState {
    isPaused: boolean;
    currentTime: number;
    duration: number;
    index: number;
}
export declare class Track<TTrackMetadata> {
    private playbackType;
    private webAudioLoadingState;
    private loadedHead;
    private queue;
    private audio;
    private audioContext;
    private gainNode;
    private webAudioStartedPlayingAt;
    private webAudioPausedAt;
    private webAudioPausedDuration;
    private audioBuffer;
    private bufferSourceNode;
    metadata: TTrackMetadata;
    index: number;
    trackUrl: string;
    constructor({ trackUrl, queue, index, metadata }: TrackOptions<TTrackMetadata>);
    pause(): void;
    play(): Promise<void>;
    togglePlayPause(): Promise<void>;
    preload(useHtmlAudioPreloading?: boolean): void;
    seek(to?: number): void;
    connectGainNode(): void;
    setVolume(volume: number): void;
    get isUsingWebAudio(): boolean;
    get isPaused(): boolean;
    get currentTime(): number;
    get duration(): number;
    get isActiveTrack(): boolean;
    get isLoaded(): boolean;
    get state(): LimitedTrackState;
    get completeState(): TrackState;
    private loadHEAD;
    private loadBuffer;
    private switchToWebAudio;
    private seekBufferSourceNode;
    private notifyTrackEnd;
    private onProgress;
    private debug;
}
export {};
